@@ -48,7 +48,7 @@ class PipelineOperator:
 
     def submit_pipeline_data(self):
         from azure.storage.blob import ContainerClient
-        conn_string = os[self.CONNECTION_STRING_NAME]
+        conn_string = os.environ[self.CONNECTION_STRING_NAME]
         container_client = ContainerClient.from_connection_string(
             conn_str=conn_string, container_name=self.CONTAINTER_NAME)
         for file_name in [self.OUTPUT_NAME_CSV, self.OUTPUT_NAME_JSON]:
